API reference
=============

``appsettings.AppSettings`` class
---------------------------------

.. autoclass:: appsettings.AppSettings
    :members:

``appsettings.Setting`` and subclasses
--------------------------------------

.. autoclass:: appsettings.Setting
    :members:

.. autoclass:: appsettings.BooleanSetting
    :members:

.. autoclass:: appsettings.IntegerSetting
    :members:

.. autoclass:: appsettings.PositiveIntegerSetting
    :members:

.. autoclass:: appsettings.FloatSetting
    :members:

.. autoclass:: appsettings.PositiveFloatSetting
    :members:

``appsettings.IterableSetting`` and subclasses
----------------------------------------------

.. autoclass:: appsettings.IterableSetting
    :members:

.. autoclass:: appsettings.StringSetting
    :members:

.. autoclass:: appsettings.ListSetting
    :members:

.. autoclass:: appsettings.SetSetting
    :members:

.. autoclass:: appsettings.TupleSetting
    :members:

``appsettings.DictSetting`` setting
-----------------------------------

.. autoclass:: appsettings.DictSetting
    :members:

``appsettings.ObjectSetting`` setting
-------------------------------------

.. autoclass:: appsettings.ObjectSetting
    :members:

``appsettings.NestedSetting`` setting
-------------------------------------

.. autoclass:: appsettings.NestedSetting
    :members:

``appsettings.TypeChecker`` and subclasses
------------------------------------------

.. autoclass:: appsettings.TypeChecker
    :members:

.. autoclass:: appsettings.BooleanTypeChecker
    :members:

.. autoclass:: appsettings.IntegerTypeChecker
    :members:

.. autoclass:: appsettings.FloatTypeChecker
    :members:

``appsettings.IterableTypeChecker`` and subclasses
--------------------------------------------------

.. autoclass:: appsettings.IterableTypeChecker
    :members:

.. autoclass:: appsettings.StringTypeChecker
    :members:

.. autoclass:: appsettings.ListTypeChecker
    :members:

.. autoclass:: appsettings.SetTypeChecker
    :members:

.. autoclass:: appsettings.TupleTypeChecker
    :members:

``appsettings.DictTypeChecker`` checker
---------------------------------------

.. autoclass:: appsettings.DictTypeChecker
    :members:

``appsettings.ObjectTypeChecker`` checker
-----------------------------------------

.. autoclass:: appsettings.ObjectTypeChecker
    :members:
